==> dde-network-core_1.0.61.orig.tar.xz: dde-network-core-1.0.61/dss-network-plugin/translations/dss-network-plugin_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 novo sporočilo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 je povezan</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Žična povezava</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Dostopna točka</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Vrsta varnosti</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pas</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Vmesnik</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Omrežna maska</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Prehod</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Prednostni DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Predpona</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hitrost</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Naprava onemogočena</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Povezano, brez dostopa do spleta</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Brez povezave</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Omrežni kabel je izklopljen</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Povezovanje</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Overjanje</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Pridobivanje IP naslova</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Povezava vzpostavljena</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Povezava prekinjena</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP spor</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Ni uspelo</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Pridobivanje naslova</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Ožičeno omrežje</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Žično omrežje %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Brezžično omrežje</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Brezžično omrežje %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Naprava onemogočena</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Omrežni kabel je izklopljen</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Brez povezave</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Povezovanje</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Povezano, brez dostopa do spleta</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Povezava ni uspela</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP spor</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Onemogoči žično povezavo</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Omogoči žično povezavo</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Onemogoči brezžično povezavo</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Omogoči brezžično povezavo</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Onemogoči omrežje</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Omogoči omrežje</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Nastavitve omrežja</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.2.orig.tar.xz: dde-network-core-1.1.2/dss-network-plugin/translations/dss-network-plugin_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 novo sporočilo</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Brezžično omrežje</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Ožičeno omrežje</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 je povezan</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Povezava na skrito omrežje</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Prekini</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Poveži</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Dostopna točka</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Vrsta varnosti</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pas</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Vmesnik</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Omrežna maska</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Prehod</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Prednostni DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Predpona</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hitrost</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Naprava onemogočena</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Povezano, brez dostopa do spleta</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Brez povezave</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Omrežni kabel je izklopljen</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Povezovanje</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Overjanje</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Pridobivanje IP naslova</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Povezava vzpostavljena</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Povezava prekinjena</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP spor</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Ni uspelo</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Pridobivanje naslova</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Ožičeno omrežje</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Žično omrežje %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Brezžično omrežje</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Brezžično omrežje %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Naprava onemogočena</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Omrežni kabel je izklopljen</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Brez povezave</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Povezovanje</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Povezano, brez dostopa do spleta</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Povezava ni uspela</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP spor</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Onemogoči žično povezavo</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Omogoči žično povezavo</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Onemogoči brezžično povezavo</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Omogoči brezžično povezavo</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Onemogoči omrežje</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Omogoči omrežje</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Nastavitve omrežja</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Žična povezava</translation>
    </message>
</context>
</TS>
